psychopy_ext.exp.Event — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Event

class `psychopy_ext.exp.` `Event`(parent, name='', dur=0.3, durcol=None, display=None, func=None)

  Defines event displays.

  Args: | parent (`Experiment` or `Task`)
  Kwargs: | name (str, default: ‘’) Event name. dur (int/float or a list of int/float, default: .300) Event duration (in seconds). If events have different durations throughout experiment, you can provide a list of durations which must be of the same length as the number of trials. display (stimulus or a list of stimuli, default: None) Stimuli that are displayed during this event. If None, displays a fixation spot (or, if not created, creates one first). func (function, default: None) Function to perform . If None, defaults to `idle_event()`.

  `__init__`(parent, name='', dur=0.3, durcol=None, display=None, func=None)

    Defines event displays.

    Args: | parent (`Experiment` or `Task`)
    Kwargs: | name (str, default: ‘’) Event name. dur (int/float or a list of int/float, default: .300) Event duration (in seconds). If events have different durations throughout experiment, you can provide a list of durations which must be of the same length as the number of trials. display (stimulus or a list of stimuli, default: None) Stimuli that are displayed during this event. If None, displays a fixation spot (or, if not created, creates one first). func (function, default: None) Function to perform . If None, defaults to `idle_event()`.

  Methods

  `__init__`(parent[, name, dur, durcol, ...]) | Defines event displays.